/*
 * lennard_jones.h - lennard jones potential header file
 *
 * author: Frank Zirkelbach <frank.zirkelbach@physik.uni-augsburg.de>
 *
 */

#ifndef LENNARD_JONES_H
#define LENNARD_JONES_H

/* types */
typedef struct s_lj_params {
	double sigma6;
	double sigma12;
	double epsilon4;
	double uc;
} t_lj_params;

/* function prototype */
int lennard_jones_set_params(t_moldyn *moldyn,int element);
int lennard_jones(t_moldyn *moldyn,t_atom *ai,t_atom *aj,u8 bc);
int lennard_jones_check_2b_bond(t_moldyn *moldyn,t_atom *ai,t_atom *aj,u8 bc);

/* lennard jones potential parameters */

// silicon
#define LJ_SIGMA_SI		((0.25*sqrt(3.0)*LC_SI)/1.122462)
#define LJ_EPSILON_SI		(2.1678*EV) // TODO

// carbob
#define LJ_SIGMA_C		((0.25*sqrt(3.0)*LC_C)/1.122462)
#define LJ_EPSILON_C		(2.1678*EV) // TODO

#endif
