/*
 * code searching for special types of bonds
 *
 * author: frank.zirkelbach@physik.uni-augsburg.de
 *
 */

#define _GNU_SOURCE
#include <stdio.h>
//#include <stdlib.h>
//#include <unistd.h>
//#include <string.h>
//#include <sys/types.h>
//#include <sys/stat.h>
//#include <fcntl.h>

#include "moldyn.h"
#include "potentials/albe.h"

typedef struct s_data {
	double pm,len;
	u8 type;
} t_data;

int usage(char *prog) {

	printf("\nusage:\n");
	printf("  %s <file> <type> <bondlen> <+->\n",prog);
	printf("    type: a - 0-0 bond\n");
	printf("    type: b - 1-1 bond\n");
	printf("    type: c - 0-1 / 1-0  bond\n\n");

	return -1;
}

int process(t_moldyn *moldyn,t_atom *ai,t_atom *aj,void *ptr,u8 bc) {

	t_3dvec dist;
	double d;
	t_data *data;

	data=ptr;

	if(aj<ai)
		return 0;

	switch(data->type) {
		case 'a':
			if(ai->brand!=0)
				return 0;
			if(aj->brand!=0)
				return 0;
				
			break;
		case 'b':
			if(ai->brand!=1)
				return 0;
			if(aj->brand!=1)
				return 0;
			break;
		default:
			if(ai->brand==aj->brand)
				return 0;
			break;
	}

	v3_sub(&dist,&(ai->r),&(aj->r));
	check_per_bound(moldyn,&dist);
	d=v3_norm(&dist);

	if((d<=data->len+data->pm)&(d>=data->len-data->pm))
		printf(" # atoms %d/%d %d/%d - %f\n",
		       ai->tag,ai->brand,
		       aj->tag,aj->brand,d);

	return 0;
}

int main(int argc,char **argv) {

	t_moldyn moldyn;
	int ret;
	t_data data;

	if(argc!=5) {
		usage(argv[0]);
		return -1;
	}

	data.type=argv[2][0];
	data.len=atof(argv[3]);
	data.pm=atof(argv[4]);

	memset(&moldyn,0,sizeof(t_moldyn));

	printf("[search bonds] reading save file ...\n");
	ret=moldyn_read_save_file(&moldyn,argv[1]);
	if(ret) {
		printf("[search bonds] exit!\n");
		return ret;
	}

	/* link cell init */
	moldyn.cutoff=data.len+data.pm;
	link_cell_init(&moldyn,VERBOSE);

	process_2b_bonds(&moldyn,&data,process);

	/* analyzing ... */
	link_cell_shutdown(&moldyn);

	moldyn_free_save_file(&moldyn);

	return 0;
}
